from third_sdk.jd.api.base import RestApi

class MfaInnerSendCodeToMobileRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.rKey = None
			self.validateType = None

		def getapiname(self):
			return 'jingdong.mfa.inner.sendCodeToMobile'

			








from third_sdk.jd.api.rest.UnionOpenGoodsQueryRequest import UnionOpenGoodsQueryRequest
from third_sdk.jd.api.base import RestApi
from third_sdk.jd import appinfo
import time
import json
import hashlib
import requests
from urllib import parse
from typing import Union


SYSTEM_GENERATE_VERSION = "taobao-sdk-python-fengjinqi"

P_APPKEY = "app_key"
P_API = "method"
P_ACCESS_TOKEN = "access_token"
P_VERSION = "v"
P_FORMAT = "format"
P_TIMESTAMP = "timestamp"
P_SIGN = "sign"
P_JSON_PARAM_KEY = "360buy_param_json"

P_CODE = 'code'
P_SUB_CODE = 'sub_code'
P_MSG = 'msg'
P_SUB_MSG = 'sub_msg'

N_REST = '/routerjson'

def _get_request_header():
    return {
             "Connection": "Close",
    }

class JdClient:

    def __init__(self, host='https://api.jd.com/routerjson', port=80, appkey='', secret='', timeout=30):
        self.__host = host
        self.__port = port
        self.__appkey = appkey
        self.__secret = secret
        self.__timeout = timeout

    def jd_union_open_goods_query(self, api: Union[UnionOpenGoodsQueryRequest, str] = None, access_token=None,
                                  **kwargs) -> requests.Response:
        if api is None:
            api = UnionOpenGoodsQueryRequest(self.__host, self.__port)
        return self.api_invoke(api, access_token, **kwargs)

    def api_invoke(self, api: Union[RestApi, str], access_token=None, version="1.0", method='POST', **kwargs) -> requests.Response:
        assert api is not None

        if type(api) == str:
            return _api_invoke(self.__host, method, self.__appkey, self.__secret, api, version, access_token, self.__timeout, **kwargs)

        api.set_app_info(appinfo(self.__appkey, self.__secret))
        for k, v in kwargs.items():
            setattr(api, k, v)
        return api.getResponse(access_token=access_token, timeout=self.__timeout)


def _get_application_parameters(**kwargs):
    application_parameter = {}
    for key, value in kwargs.items():
        if key and value:
            if key.startswith("_"):
                application_parameter[key[1:]] = value
            else:
                application_parameter[key] = value
    return application_parameter


def _sign(secret, parameters):
    str_parameters = ""
    if hasattr(parameters, "items"):
        keys = sorted(parameters.keys())
        str_parameters = "%s%s%s" % (secret,
                                     str().join('%s%s' % (key, parameters[key]) for key in keys),
                                     secret)
    a_sign = hashlib.md5(str_parameters.encode("utf-8")).hexdigest().upper()
    return a_sign


def _api_invoke(domain, http_method, appkey, secret, apiname, version, access_token, timeout, **kwargs):
    sys_parameters = {
        P_APPKEY: appkey,
        P_VERSION: version,
        P_API: apiname,
        P_TIMESTAMP: time.strftime("%Y-%m-%d %H:%M:%S.000%z", time.localtime()),
    }
    if access_token is not None:
        sys_parameters[P_ACCESS_TOKEN] = access_token
    if not domain.startswith('http'):
        url = 'http://' + domain
    else:
        url = domain
    if not url.endswith(N_REST) and not url.endswith(N_REST + '/'):
        url = url[:-1] if url.endswith('/') else url
        url = url + N_REST

    application_parameter = _get_application_parameters(**kwargs)
    sys_parameters[P_JSON_PARAM_KEY] = json.dumps(application_parameter, ensure_ascii=False,
                                                  default=lambda value: value.__dict__)
    sys_parameters[P_SIGN] = _sign(secret, sys_parameters)
    if http_method == 'POST':
        return requests.post(url, data=sys_parameters, headers=_get_request_header(), timeout=timeout)
    else:
        url = url + "?" + parse.urlencode(sys_parameters)
        return requests.get(url, headers=_get_request_header(), timeout=timeout)



from third_sdk.jd.api.base import RestApi

class UnionOpenPromotionCommonGetRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.promotionCodeReq = None

		def getapiname(self):
			return 'jd.union.open.promotion.common.get'

		def get_version(self):
			return '1.0'
			
	

class PromotionCodeReq(object):
		def __init__(self):
			"""
			"""
			self.materialId = None
			self.siteId = None
			self.positionId = None
			self.subUnionId = None
			self.ext1 = None
			self.protocol = None
			self.pid = None
			self.couponUrl = None
			self.giftCouponKey = None








from third_sdk.jd.api.rest.UnionOpenGoodsJingfenQueryRequest import UnionOpenGoodsJingfenQueryRequest
from third_sdk.jd.api.rest.UnionOpenOrderQueryRequest import UnionOpenOrderQueryRequest
from third_sdk.jd.api.rest.ServiceActivityInfoReportRequest import ServiceActivityInfoReportRequest
from third_sdk.jd.api.rest.KplOpenMigumusicCheckstatusRequest import KplOpenMigumusicCheckstatusRequest
from third_sdk.jd.api.rest.KplOpenOrderFindchildorderbyparentRequest import KplOpenOrderFindchildorderbyparentRequest
from third_sdk.jd.api.rest.KplOpenMigumusicDeliverandactivecodeRequest import KplOpenMigumusicDeliverandactivecodeRequest
from third_sdk.jd.api.rest.KplOpenPolcenterSubscribemobileRequest import KplOpenPolcenterSubscribemobileRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketApplyaftermarketRequest import KeplerSettledAftermarketApplyaftermarketRequest
from third_sdk.jd.api.rest.KplOpenJdrepairGetinfoRequest import KplOpenJdrepairGetinfoRequest
from third_sdk.jd.api.rest.MfaInnerUserUnifiedAuthenticationRequest import MfaInnerUserUnifiedAuthenticationRequest
from third_sdk.jd.api.rest.KplOpenOrderInfoQueryorderRequest import KplOpenOrderInfoQueryorderRequest
from third_sdk.jd.api.rest.KplOpenWareZhaoshangGoodsQueryRequest import KplOpenWareZhaoshangGoodsQueryRequest
from third_sdk.jd.api.rest.KplOpenPolcenterGetexpressinfoRequest import KplOpenPolcenterGetexpressinfoRequest
from third_sdk.jd.api.rest.KplOpenGetsellpriceQueryRequest import KplOpenGetsellpriceQueryRequest
from third_sdk.jd.api.rest.KplOpenItemQuerythirtydaysummaryRequest import KplOpenItemQuerythirtydaysummaryRequest
from third_sdk.jd.api.rest.KplOpenConfirmreceivedQueryRequest import KplOpenConfirmreceivedQueryRequest
from third_sdk.jd.api.rest.ProductCheckAreaLimitQueryRequest import ProductCheckAreaLimitQueryRequest
from third_sdk.jd.api.rest.MfaInnerValidateMsgCodeRequest import MfaInnerValidateMsgCodeRequest
from third_sdk.jd.api.rest.MfaInnerEliminateRiskRequest import MfaInnerEliminateRiskRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketGetbackmodeRequest import KeplerSettledAftermarketGetbackmodeRequest
from third_sdk.jd.api.rest.SearchWareRequest import SearchWareRequest
from third_sdk.jd.api.rest.MfaInnerSendCodeToMobileRequest import MfaInnerSendCodeToMobileRequest
from third_sdk.jd.api.rest.WirelessWarePriceGetRequest import WirelessWarePriceGetRequest
from third_sdk.jd.api.rest.UserGetUserInfoByOpenIdRequest import UserGetUserInfoByOpenIdRequest
from third_sdk.jd.api.rest.UnionOpenPromotionByunionidGetRequest import UnionOpenPromotionByunionidGetRequest
from third_sdk.jd.api.rest.UnionOpenPositionQueryRequest import UnionOpenPositionQueryRequest
from third_sdk.jd.api.rest.YsdkMemberApplyJsfServiceSaveMemberAndProtocolInfoRequest import YsdkMemberApplyJsfServiceSaveMemberAndProtocolInfoRequest
from third_sdk.jd.api.rest.OpenBlueInvoiceUploadRequest import OpenBlueInvoiceUploadRequest
from third_sdk.jd.api.rest.UnionOpenPositionCreateRequest import UnionOpenPositionCreateRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketSaveaftermarketRequest import KeplerSettledAftermarketSaveaftermarketRequest
from third_sdk.jd.api.rest.UnionOpenGoodsQueryRequest import UnionOpenGoodsQueryRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketGetreturnedwayRequest import KeplerSettledAftermarketGetreturnedwayRequest
from third_sdk.jd.api.rest.UnionOpenGoodsPromotiongoodsinfoQueryRequest import UnionOpenGoodsPromotiongoodsinfoQueryRequest
from third_sdk.jd.api.rest.KplOpenWeiboCartAddRequest import KplOpenWeiboCartAddRequest
from third_sdk.jd.api.rest.UnionOpenPromotionCommonGetRequest import UnionOpenPromotionCommonGetRequest
from third_sdk.jd.api.rest.UnionOpenPromotionBysubunionidGetRequest import UnionOpenPromotionBysubunionidGetRequest
from third_sdk.jd.api.rest.UnionOpenCouponQueryRequest import UnionOpenCouponQueryRequest
from third_sdk.jd.api.rest.PriceSellPriceGetRequest import PriceSellPriceGetRequest
from third_sdk.jd.api.rest.ProductStateQueryRequest import ProductStateQueryRequest
from third_sdk.jd.api.rest.ProductDetailQueryRequest import ProductDetailQueryRequest
from third_sdk.jd.api.rest.KplOpenWfpJmiwareAddWareRequest import KplOpenWfpJmiwareAddWareRequest
from third_sdk.jd.api.rest.KplOpenFalvwangRequestRequest import KplOpenFalvwangRequestRequest
from third_sdk.jd.api.rest.KplOpenTradeTencentOrderlistRequest import KplOpenTradeTencentOrderlistRequest
from third_sdk.jd.api.rest.KplOpenWfpJmiwareUpdateWareStatusRequest import KplOpenWfpJmiwareUpdateWareStatusRequest
from third_sdk.jd.api.rest.KeplerXuanpinCpsurlConvertRequest import KeplerXuanpinCpsurlConvertRequest
from third_sdk.jd.api.rest.KplOpenWfpVscLegalOrderRequest import KplOpenWfpVscLegalOrderRequest
from third_sdk.jd.api.rest.KeplerXuanpinGenclickurlBatchRequest import KeplerXuanpinGenclickurlBatchRequest
from third_sdk.jd.api.rest.JsfXbXBProductServiceQueryProductsRequest import JsfXbXBProductServiceQueryProductsRequest
from third_sdk.jd.api.rest.KplOpenWfpJmiwareEditWareRequest import KplOpenWfpJmiwareEditWareRequest
from third_sdk.jd.api.rest.KplOpenReportUploadRequest import KplOpenReportUploadRequest
from third_sdk.jd.api.rest.KplOpenAlphaHandleventRequest import KplOpenAlphaHandleventRequest
from third_sdk.jd.api.rest.KeplerOrderGetordertrackRequest import KeplerOrderGetordertrackRequest
from third_sdk.jd.api.rest.UnionOpenOrderAgentQueryRequest import UnionOpenOrderAgentQueryRequest
from third_sdk.jd.api.rest.KeplerTradeGetstockRequest import KeplerTradeGetstockRequest
from third_sdk.jd.api.rest.KplOpenMigumusicUnbinddeviceRequest import KplOpenMigumusicUnbinddeviceRequest
from third_sdk.jd.api.rest.KplOpenYaoMultipriceUpdateRequest import KplOpenYaoMultipriceUpdateRequest
from third_sdk.jd.api.rest.KplOpenShopGoodsListRequest import KplOpenShopGoodsListRequest
from third_sdk.jd.api.rest.KplOpenYaoShelfstateBatchupdateRequest import KplOpenYaoShelfstateBatchupdateRequest
from third_sdk.jd.api.rest.UnionOpenOrderRowQueryRequest import UnionOpenOrderRowQueryRequest
from third_sdk.jd.api.rest.KeplerOrderCancelorderRequest import KeplerOrderCancelorderRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketQueryservicepageRequest import KeplerSettledAftermarketQueryservicepageRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketQueryservicedetailRequest import KeplerSettledAftermarketQueryservicedetailRequest
from third_sdk.jd.api.rest.KplOpenWfpVscVerifiedNotifyRequest import KplOpenWfpVscVerifiedNotifyRequest
from third_sdk.jd.api.rest.KplOpenCommentCommentlistRequest import KplOpenCommentCommentlistRequest
from third_sdk.jd.api.rest.KplOpenTradeGetorderrefundRequest import KplOpenTradeGetorderrefundRequest
from third_sdk.jd.api.rest.KplOpenWfpVscMakeCertCallbackRequest import KplOpenWfpVscMakeCertCallbackRequest
from third_sdk.jd.api.rest.KplOpenAlphaConfigAddrsgetRequest import KplOpenAlphaConfigAddrsgetRequest
from third_sdk.jd.api.rest.KplOpenWfpVscPreviewRequest import KplOpenWfpVscPreviewRequest
from third_sdk.jd.api.rest.UnionOpenSellingOrderRowQueryRequest import UnionOpenSellingOrderRowQueryRequest
from third_sdk.jd.api.rest.UnionOpenGoodsLinkQueryRequest import UnionOpenGoodsLinkQueryRequest
from third_sdk.jd.api.rest.InvoiceWaybillRequest import InvoiceWaybillRequest
from third_sdk.jd.api.rest.OrderJdOrderIDByThridOrderIDQueryRequest import OrderJdOrderIDByThridOrderIDQueryRequest
from third_sdk.jd.api.rest.KplOpenAftersaleOrderidRequest import KplOpenAftersaleOrderidRequest
from third_sdk.jd.api.rest.KplOpenAlphaHandleRequest import KplOpenAlphaHandleRequest
from third_sdk.jd.api.rest.KplOpenRegularPlanQueryplancountRequest import KplOpenRegularPlanQueryplancountRequest
from third_sdk.jd.api.rest.KplOpenRegularPlanCompletedorderRequest import KplOpenRegularPlanCompletedorderRequest
from third_sdk.jd.api.rest.KplOpenSkuQueryinfoRequest import KplOpenSkuQueryinfoRequest
from third_sdk.jd.api.rest.KeplerXuanpinSearchSkuRequest import KeplerXuanpinSearchSkuRequest
from third_sdk.jd.api.rest.KplOpenJdrepairSaveaddressRequest import KplOpenJdrepairSaveaddressRequest
from third_sdk.jd.api.rest.KplOpenRegularPlanCancleplanRequest import KplOpenRegularPlanCancleplanRequest
from third_sdk.jd.api.rest.KplOpenYaoOrdersyncListRequest import KplOpenYaoOrdersyncListRequest
from third_sdk.jd.api.rest.KeplerXuanpinSearchSkuRequest import KeplerXuanpinSearchSkuRequest
from third_sdk.jd.api.rest.MessageGetRequest import MessageGetRequest
from third_sdk.jd.api.rest.AfterSaleServiceListPageQueryRequest import AfterSaleServiceListPageQueryRequest
from third_sdk.jd.api.rest.KplOpenTradeMasterGetcouponlistRequest import KplOpenTradeMasterGetcouponlistRequest
from third_sdk.jd.api.rest.KeplerXuanpinGetpkglistRequest import KeplerXuanpinGetpkglistRequest
from third_sdk.jd.api.rest.KeplerXuanpinSearchSkuByCategoryRequest import KeplerXuanpinSearchSkuByCategoryRequest
from third_sdk.jd.api.rest.NewWareBaseproductGetRequest import NewWareBaseproductGetRequest
from third_sdk.jd.api.rest.UnionOpenStatisticsRedpacketQueryRequest import UnionOpenStatisticsRedpacketQueryRequest
from third_sdk.jd.api.rest.BizProductGetSimilarSkuRequest import BizProductGetSimilarSkuRequest
from third_sdk.jd.api.rest.KplOpenXdpSoaGetSessionIdRequest import KplOpenXdpSoaGetSessionIdRequest
from third_sdk.jd.api.rest.KplOpenItemFindcanusecouponsRequest import KplOpenItemFindcanusecouponsRequest
from third_sdk.jd.api.rest.ProductDetailQueryRequest import ProductDetailQueryRequest
from third_sdk.jd.api.rest.KplOpenRankInfoGatherServiceRequest import KplOpenRankInfoGatherServiceRequest
from third_sdk.jd.api.rest.UnionOpenActivityRecommendQueryRequest import UnionOpenActivityRecommendQueryRequest
from third_sdk.jd.api.rest.UnionOpenCouponGiftStopRequest import UnionOpenCouponGiftStopRequest
from third_sdk.jd.api.rest.NewWareBaseproductGetRequest import NewWareBaseproductGetRequest
from third_sdk.jd.api.rest.KeplerYaoWareStockUpdateRequest import KeplerYaoWareStockUpdateRequest
from third_sdk.jd.api.rest.KeplerItemQuerybigfieldconvertskuRequest import KeplerItemQuerybigfieldconvertskuRequest
from third_sdk.jd.api.rest.KplOpenYaoOrdersyncUpdatestateRequest import KplOpenYaoOrdersyncUpdatestateRequest
from third_sdk.jd.api.rest.NewWareMobilebigfieldGetRequest import NewWareMobilebigfieldGetRequest
from third_sdk.jd.api.rest.KplOpenYaoPropertyUpdateRequest import KplOpenYaoPropertyUpdateRequest
from third_sdk.jd.api.rest.KplOpenItemFindjoinactivesRequest import KplOpenItemFindjoinactivesRequest
from third_sdk.jd.api.rest.KeplerYaoWarePriceUpdateRequest import KeplerYaoWarePriceUpdateRequest
from third_sdk.jd.api.rest.KplOpenPromiseDosConfigRequest import KplOpenPromiseDosConfigRequest
from third_sdk.jd.api.rest.KplOpenAlphaGetconfigurewithloginRequest import KplOpenAlphaGetconfigurewithloginRequest
from third_sdk.jd.api.rest.ProductSkuQueryRequest import ProductSkuQueryRequest
from third_sdk.jd.api.rest.KplOpenRegularPlanQueryplanlistnewRequest import KplOpenRegularPlanQueryplanlistnewRequest
from third_sdk.jd.api.rest.OpenOrderGetorderlistRequest import OpenOrderGetorderlistRequest
from third_sdk.jd.api.rest.UnionOpenCouponGiftGetRequest import UnionOpenCouponGiftGetRequest
from third_sdk.jd.api.rest.WareProductCatelogyListGetRequest import WareProductCatelogyListGetRequest
from third_sdk.jd.api.rest.UnionOpenStatisticsGiftcouponQueryRequest import UnionOpenStatisticsGiftcouponQueryRequest
from third_sdk.jd.api.rest.ProductCommentSummarysQueryRequest import ProductCommentSummarysQueryRequest
from third_sdk.jd.api.rest.AfterSaleWareReturnJdCompQueryRequest import AfterSaleWareReturnJdCompQueryRequest
from third_sdk.jd.api.rest.KplOpenXuanpinSearchgoodsRequest import KplOpenXuanpinSearchgoodsRequest
from third_sdk.jd.api.rest.OrderJdOrderQueryRequest import OrderJdOrderQueryRequest
from third_sdk.jd.api.rest.BizProductGetcategoryRequest import BizProductGetcategoryRequest
from third_sdk.jd.api.rest.KplOpenMigumusicChannelkeyRequest import KplOpenMigumusicChannelkeyRequest
from third_sdk.jd.api.rest.UnionOpenSellingPromotionGetRequest import UnionOpenSellingPromotionGetRequest
from third_sdk.jd.api.rest.KplOpenPolcenterSubscribeorderRequest import KplOpenPolcenterSubscribeorderRequest
from third_sdk.jd.api.rest.KeplerOrderGetorderdetailRequest import KeplerOrderGetorderdetailRequest
from third_sdk.jd.api.rest.KplOpenPopEnsuregettinggoodsRequest import KplOpenPopEnsuregettinggoodsRequest
from third_sdk.jd.api.rest.PriceBalanceQueryRequest import PriceBalanceQueryRequest
from third_sdk.jd.api.rest.UnionOpenPromotionParseRequest import UnionOpenPromotionParseRequest
from third_sdk.jd.api.rest.KplOpenPolcenterGetexttraceRequest import KplOpenPolcenterGetexttraceRequest
from third_sdk.jd.api.rest.KeplerXuanpinSkuPromotionBatchRequest import KeplerXuanpinSkuPromotionBatchRequest
from third_sdk.jd.api.rest.KplOpenPolcenterUnsubscribemobileRequest import KplOpenPolcenterUnsubscribemobileRequest
from third_sdk.jd.api.rest.KeplerTradeSubmitRequest import KeplerTradeSubmitRequest
from third_sdk.jd.api.rest.KplOpenTradeMasterUsecouponRequest import KplOpenTradeMasterUsecouponRequest
from third_sdk.jd.api.rest.KplOpenBatchConvertCpslinkRequest import KplOpenBatchConvertCpslinkRequest
from third_sdk.jd.api.rest.KplOpenClientGetunplRequest import KplOpenClientGetunplRequest
from third_sdk.jd.api.rest.KplOpenCpsConvertKeplerurlRequest import KplOpenCpsConvertKeplerurlRequest
from third_sdk.jd.api.rest.AddressAllProvincesQueryRequest import AddressAllProvincesQueryRequest
from third_sdk.jd.api.rest.KplOpenAftermarketRefundRequest import KplOpenAftermarketRefundRequest
from third_sdk.jd.api.rest.PopOrderGetmobilelistRequest import PopOrderGetmobilelistRequest
from third_sdk.jd.api.rest.OrderOrderTrackQueryRequest import OrderOrderTrackQueryRequest
from third_sdk.jd.api.rest.ProductSkuGiftQueryRequest import ProductSkuGiftQueryRequest
from third_sdk.jd.api.rest.UnionOpenGoodsBigfieldQueryRequest import UnionOpenGoodsBigfieldQueryRequest
from third_sdk.jd.api.rest.ProductSkuImageQueryRequest import ProductSkuImageQueryRequest
from third_sdk.jd.api.rest.KplOpenAlphashoppingconfSaveinfoRequest import KplOpenAlphashoppingconfSaveinfoRequest
from third_sdk.jd.api.rest.KeplerSkuProductServiceRequest import KeplerSkuProductServiceRequest
from third_sdk.jd.api.rest.ProductSkuCheckRequest import ProductSkuCheckRequest
from third_sdk.jd.api.rest.KplOpenQuerypingpouGetcpsskubypageRequest import KplOpenQuerypingpouGetcpsskubypageRequest
from third_sdk.jd.api.rest.KplOpenUnionSearchByelitedRequest import KplOpenUnionSearchByelitedRequest
from third_sdk.jd.api.rest.KplOpenPromotionPidurlconvertRequest import KplOpenPromotionPidurlconvertRequest
from third_sdk.jd.api.rest.KplOpenXunpinSearchCouponRequest import KplOpenXunpinSearchCouponRequest
from third_sdk.jd.api.rest.KplOpenItemGetmobilewarestyleandjsbywareidRequest import KplOpenItemGetmobilewarestyleandjsbywareidRequest
from third_sdk.jd.api.rest.AfterSaleCustomerExpectCompQueryRequest import AfterSaleCustomerExpectCompQueryRequest
from third_sdk.jd.api.rest.KplOpenItemGetwarestyleandjsbywareidRequest import KplOpenItemGetwarestyleandjsbywareidRequest
from third_sdk.jd.api.rest.BizProductGetSkuByPageRequest import BizProductGetSkuByPageRequest
from third_sdk.jd.api.rest.OrderDoPayRequest import OrderDoPayRequest
from third_sdk.jd.api.rest.OrderCheckRefuseOrderQueryRequest import OrderCheckRefuseOrderQueryRequest
from third_sdk.jd.api.rest.KplOpenNosecretpayClosesignRequest import KplOpenNosecretpayClosesignRequest
from third_sdk.jd.api.rest.KplOpenItemQuerybookbigfieldRequest import KplOpenItemQuerybookbigfieldRequest
from third_sdk.jd.api.rest.AfterSaleAfsApplyCreateRequest import AfterSaleAfsApplyCreateRequest
from third_sdk.jd.api.rest.WareProductbigfieldGetRequest import WareProductbigfieldGetRequest
from third_sdk.jd.api.rest.OrderCheckDlokOrderQueryRequest import OrderCheckDlokOrderQueryRequest
from third_sdk.jd.api.rest.KplOpenNosecretpaySavetokenRequest import KplOpenNosecretpaySavetokenRequest
from third_sdk.jd.api.rest.KeplerOrderDefrayRequest import KeplerOrderDefrayRequest
from third_sdk.jd.api.rest.KplOpenAreaCheckareaRequest import KplOpenAreaCheckareaRequest
from third_sdk.jd.api.rest.UnionOpenExtraDeliverymanValidateRequest import UnionOpenExtraDeliverymanValidateRequest
from third_sdk.jd.api.rest.KplOpenNosecretpaySavesignedRequest import KplOpenNosecretpaySavesignedRequest
from third_sdk.jd.api.rest.BizProductGetcategorysRequest import BizProductGetcategorysRequest
from third_sdk.jd.api.rest.KplOpenSeckillKeplerqbRequest import KplOpenSeckillKeplerqbRequest
from third_sdk.jd.api.rest.AfterSaleSendSkuUpdateRequest import AfterSaleSendSkuUpdateRequest
from third_sdk.jd.api.rest.KplOpenKeplerQuerySkudescriptionRequest import KplOpenKeplerQuerySkudescriptionRequest
from third_sdk.jd.api.rest.OrderOccupyStockConfirmRequest import OrderOccupyStockConfirmRequest
from third_sdk.jd.api.rest.OrderCancelorderRequest import OrderCancelorderRequest
from third_sdk.jd.api.rest.KplOpenNbdMedicineGetricendtockRequest import KplOpenNbdMedicineGetricendtockRequest
from third_sdk.jd.api.rest.MessageDelRequest import MessageDelRequest
from third_sdk.jd.api.rest.KeplerXuanpinGetskuidlistRequest import KeplerXuanpinGetskuidlistRequest
from third_sdk.jd.api.rest.ProductBaseQueryRequest import ProductBaseQueryRequest
from third_sdk.jd.api.rest.UnionOpenStatisticsActivityBonusQueryRequest import UnionOpenStatisticsActivityBonusQueryRequest
from third_sdk.jd.api.rest.ProductYanbaoSkuQueryRequest import ProductYanbaoSkuQueryRequest
from third_sdk.jd.api.rest.OrderFreightGetRequest import OrderFreightGetRequest
from third_sdk.jd.api.rest.OrderPromiseCalendarGetRequest import OrderPromiseCalendarGetRequest
from third_sdk.jd.api.rest.UnionOpenSettleQueryRequest import UnionOpenSettleQueryRequest
from third_sdk.jd.api.rest.KplOpenCouponSearchSkuRequest import KplOpenCouponSearchSkuRequest
from third_sdk.jd.api.rest.StockForListBatgetRequest import StockForListBatgetRequest
from third_sdk.jd.api.rest.UnionOpenStatisticsGoodsSalesQueryRequest import UnionOpenStatisticsGoodsSalesQueryRequest
from third_sdk.jd.api.rest.JosSecretApiReportGetRequest import JosSecretApiReportGetRequest
from third_sdk.jd.api.rest.KplOpenInvoiceQuerythrapplynoRequest import KplOpenInvoiceQuerythrapplynoRequest
from third_sdk.jd.api.rest.KeplerItemGetnologinpromotionRequest import KeplerItemGetnologinpromotionRequest
from third_sdk.jd.api.rest.AfterSaleServiceDetailInfoQueryRequest import AfterSaleServiceDetailInfoQueryRequest
from third_sdk.jd.api.rest.KplOpenGetnewstockbyidQueryRequest import KplOpenGetnewstockbyidQueryRequest
from third_sdk.jd.api.rest.KplOpenRegularPlanShipmentorderRequest import KplOpenRegularPlanShipmentorderRequest
from third_sdk.jd.api.rest.KplOpenItemFindjoinactivesRequest import KplOpenItemFindjoinactivesRequest
from third_sdk.jd.api.rest.KplOpenNosecretpayGetsignurlRequest import KplOpenNosecretpayGetsignurlRequest
from third_sdk.jd.api.rest.KplOpenSelectjdorderQueryRequest import KplOpenSelectjdorderQueryRequest
from third_sdk.jd.api.rest.PriceJincaiCreditQueryRequest import PriceJincaiCreditQueryRequest
from third_sdk.jd.api.rest.OrderWaybilltrackSearchRequest import OrderWaybilltrackSearchRequest
from third_sdk.jd.api.rest.UnionOpenStatisticsRedpacketAgentQueryRequest import UnionOpenStatisticsRedpacketAgentQueryRequest
from third_sdk.jd.api.rest.ProductIsCodQueryRequest import ProductIsCodQueryRequest
from third_sdk.jd.api.rest.AddressTownsByCountyIdQueryRequest import AddressTownsByCountyIdQueryRequest
from third_sdk.jd.api.rest.KeplerServicePromotionGoodsinfoRequest import KeplerServicePromotionGoodsinfoRequest
from third_sdk.jd.api.rest.AddressCitysByProvinceIdQueryRequest import AddressCitysByProvinceIdQueryRequest
from third_sdk.jd.api.rest.MfaUserUnifiedAuthenticationRequest import MfaUserUnifiedAuthenticationRequest
from third_sdk.jd.api.rest.OrderCheckNewOrderQueryRequest import OrderCheckNewOrderQueryRequest
from third_sdk.jd.api.rest.AddressCountysByCityIdQueryRequest import AddressCountysByCityIdQueryRequest
from third_sdk.jd.api.rest.YjcFgcGetOrderDetailRequest import YjcFgcGetOrderDetailRequest
from third_sdk.jd.api.rest.OpenOrderSplitDeliverNewRequest import OpenOrderSplitDeliverNewRequest
from third_sdk.jd.api.rest.KplOpenShenzhouConfigGetRequest import KplOpenShenzhouConfigGetRequest
from third_sdk.jd.api.rest.KplOpenConfigOauthSaveRequest import KplOpenConfigOauthSaveRequest
from third_sdk.jd.api.rest.WarePriceGetRequest import WarePriceGetRequest
from third_sdk.jd.api.rest.KplOpenDingdongProtocolConvertRequest import KplOpenDingdongProtocolConvertRequest
from third_sdk.jd.api.rest.KplOpenItemQuerystockRequest import KplOpenItemQuerystockRequest
from third_sdk.jd.api.rest.UnionOpenGoodsMaterialQueryRequest import UnionOpenGoodsMaterialQueryRequest
from third_sdk.jd.api.rest.UnionOpenSellingGoodsQueryRequest import UnionOpenSellingGoodsQueryRequest
from third_sdk.jd.api.rest.ProductBaseQueryRequest import ProductBaseQueryRequest
from third_sdk.jd.api.rest.OrderUniteSubmitRequest import OrderUniteSubmitRequest
from third_sdk.jd.api.rest.KplOpenXuanpinSearchSkuRequest import KplOpenXuanpinSearchSkuRequest
from third_sdk.jd.api.rest.UnionOpenOrderSettleQueryRequest import UnionOpenOrderSettleQueryRequest
from third_sdk.jd.api.rest.KplOpenItemQuerybookbasicfieldRequest import KplOpenItemQuerybookbasicfieldRequest
from third_sdk.jd.api.rest.PriceBalanceGetRequest import PriceBalanceGetRequest
from third_sdk.jd.api.rest.KeplerItemQueryskusbycatidRequest import KeplerItemQueryskusbycatidRequest
from third_sdk.jd.api.rest.KeplerItemQuerycategoriesbyfidRequest import KeplerItemQuerycategoriesbyfidRequest
from third_sdk.jd.api.rest.BizAreaGetJDAddressFromAddressRequest import BizAreaGetJDAddressFromAddressRequest
from third_sdk.jd.api.rest.OpenRedInvoiceUploadRequest import OpenRedInvoiceUploadRequest
from third_sdk.jd.api.rest.UnionOpenActivityQueryRequest import UnionOpenActivityQueryRequest
from third_sdk.jd.api.rest.OpenGetSplitOrdersRequest import OpenGetSplitOrdersRequest
from third_sdk.jd.api.rest.UnionOpenActivityBonusQueryRequest import UnionOpenActivityBonusQueryRequest
from third_sdk.jd.api.rest.UnionDoubanBookServiceQueryBookUrlListRequest import UnionDoubanBookServiceQueryBookUrlListRequest
from third_sdk.jd.api.rest.KplOpenXimalayaGetresourceRequest import KplOpenXimalayaGetresourceRequest
from third_sdk.jd.api.rest.KplOpenSkuGetwareinfolistRequest import KplOpenSkuGetwareinfolistRequest
from third_sdk.jd.api.rest.KeplerPushmsgSaveBatchSubBehaviourRequest import KeplerPushmsgSaveBatchSubBehaviourRequest
from third_sdk.jd.api.rest.KeplerPushmsgCreateSubSendTaskRequest import KeplerPushmsgCreateSubSendTaskRequest
from third_sdk.jd.api.rest.UnionOpenOrderBonusQueryRequest import UnionOpenOrderBonusQueryRequest
from third_sdk.jd.api.rest.PopOrderEncryptMobileNumRequest import PopOrderEncryptMobileNumRequest
from third_sdk.jd.api.rest.KeplerSettledAddressGetareabymehodnameRequest import KeplerSettledAddressGetareabymehodnameRequest
from third_sdk.jd.api.rest.KeplerPushmsgSendSingleSubMsgRequest import KeplerPushmsgSendSingleSubMsgRequest
from third_sdk.jd.api.rest.KeplerPushmsgGetBusinessCodeListRequest import KeplerPushmsgGetBusinessCodeListRequest
from third_sdk.jd.api.rest.KeplerPushmsgSendBatchMsgRequest import KeplerPushmsgSendBatchMsgRequest
from third_sdk.jd.api.rest.KeplerPushmsgGetAppConfigTemplateListRequest import KeplerPushmsgGetAppConfigTemplateListRequest
from third_sdk.jd.api.rest.JosMasterKeyGetRequest import JosMasterKeyGetRequest
from third_sdk.jd.api.rest.UnionOpenUserRegisterValidateRequest import UnionOpenUserRegisterValidateRequest
from third_sdk.jd.api.rest.KplOpenAlphaHandleRequest import KplOpenAlphaHandleRequest
from third_sdk.jd.api.rest.UnionOpenPromotionAppletGetRequest import UnionOpenPromotionAppletGetRequest
from third_sdk.jd.api.rest.OpenOrderUpdateOrderStateNewRequest import OpenOrderUpdateOrderStateNewRequest
from third_sdk.jd.api.rest.YjcFgcGetOrderListRequest import YjcFgcGetOrderListRequest
from third_sdk.jd.api.rest.YsdkMemberApplyJsfServiceQueryMemberStatusRequest import YsdkMemberApplyJsfServiceQueryMemberStatusRequest
from third_sdk.jd.api.rest.YjcFgcUpdateOrderStateRequest import YjcFgcUpdateOrderStateRequest
from third_sdk.jd.api.rest.KplOpenSearchAssociationalWordRequest import KplOpenSearchAssociationalWordRequest
from third_sdk.jd.api.rest.WareBookbigfieldGetRequest import WareBookbigfieldGetRequest
from third_sdk.jd.api.rest.WareProductbigfieldGetRequest import WareProductbigfieldGetRequest
from third_sdk.jd.api.rest.UnionOpenGoodsSeckillQueryRequest import UnionOpenGoodsSeckillQueryRequest
from third_sdk.jd.api.rest.UnionOpenUserPidGetRequest import UnionOpenUserPidGetRequest
from third_sdk.jd.api.rest.NewWareMobilebigfieldGetRequest import NewWareMobilebigfieldGetRequest
from third_sdk.jd.api.rest.WareProductimageGetRequest import WareProductimageGetRequest
from third_sdk.jd.api.rest.KplOpenShopinfoSkuRequest import KplOpenShopinfoSkuRequest
from third_sdk.jd.api.rest.NewWareBaseproductGetRequest import NewWareBaseproductGetRequest
from third_sdk.jd.api.rest.UnionOpenCategoryGoodsGetRequest import UnionOpenCategoryGoodsGetRequest
from third_sdk.jd.api.rest.WareBasebookGetRequest import WareBasebookGetRequest
from third_sdk.jd.api.rest.KplOpenItemQuerycommentinfoyskusRequest import KplOpenItemQuerycommentinfoyskusRequest
from third_sdk.jd.api.rest.KplOpenItemQueryusablecouponlistbypageRequest import KplOpenItemQueryusablecouponlistbypageRequest
from third_sdk.jd.api.rest.InvoiceSubmitRequest import InvoiceSubmitRequest
from third_sdk.jd.api.rest.InvoiceQueryRequest import InvoiceQueryRequest
from third_sdk.jd.api.rest.AfterSaleAuditCancelQueryRequest import AfterSaleAuditCancelQueryRequest
from third_sdk.jd.api.rest.AfterSaleAvailableNumberCompQueryRequest import AfterSaleAvailableNumberCompQueryRequest
from third_sdk.jd.api.rest.JosVoucherInfoGetRequest import JosVoucherInfoGetRequest
from third_sdk.jd.api.rest.WareProductsortGetRequest import WareProductsortGetRequest
from third_sdk.jd.api.rest.KplOpenJsfTestRequest import KplOpenJsfTestRequest
from third_sdk.jd.api.rest.NewWareSameproductskuidsQueryRequest import NewWareSameproductskuidsQueryRequest
from third_sdk.jd.api.rest.NewWareProductsortattGetRequest import NewWareProductsortattGetRequest
from third_sdk.jd.api.rest.NewWareProductsafedaysGetRequest import NewWareProductsafedaysGetRequest
from third_sdk.jd.api.rest.NewWareAttributeGroupsQueryRequest import NewWareAttributeGroupsQueryRequest
from third_sdk.jd.api.rest.NewWareAttributesQueryRequest import NewWareAttributesQueryRequest
from third_sdk.jd.api.rest.NewWareAttributeValuesQueryRequest import NewWareAttributeValuesQueryRequest



'''
Created by auto_sdk on 2019.07.04
'''
from third_sdk.top.api.base import RestApi
class TbkCouponGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.activity_id = None
		self.item_id = None
		self.me = None

	def getapiname(self):
		return 'taobao.tbk.coupon.get'



from third_sdk.jd.api.base import RestApi

class KeplerPushmsgSaveBatchSubBehaviourRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.param = None

		def getapiname(self):
			return 'jingdong.kepler.pushmsg.saveBatchSubBehaviour'

			
	

class BusinessBehaviourJsfDto(object):
		def __init__(self):
			"""
			"""
			self.templateId = None
			self.behaviour = None
			self.businessCode = None
			self.businessId = None


class Param(object):
		def __init__(self):
			"""
			"""
			self.pin = None
			self.appid = None
			self.openid = None
			self.behaviourJsfDtoList = None








from third_sdk.jd.api.base import RestApi

class KplOpenPolcenterGetexpressinfoRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.request = None

		def getapiname(self):
			return 'jd.kpl.open.polcenter.getexpressinfo'

		def get_version(self):
			return '1.0'
			
	

class Request(object):
		def __init__(self):
			"""
			"""
			self.orderNum = None
			self.mobile = None
			self.factoryId = None
			self.androidId = None
			self.imei = None
			self.wifiMac = None
			self.clientIp = None
			self.bussName = None








from third_sdk.jd.api.base import RestApi

class OrderUniteSubmitRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.thirdOrder = None
			self.sku = None
			self.name = None
			self.province = None
			self.city = None
			self.county = None
			self.town = None
			self.address = None
			self.zip = None
			self.phone = None
			self.mobile = None
			self.email = None
			self.remark = None
			self.invoiceState = None
			self.invoiceType = None
			self.selectedInvoiceTitle = None
			self.companyName = None
			self.invoiceContent = None
			self.paymentType = None
			self.isUseBalance = None
			self.submitState = None
			self.invoiceName = None
			self.invoicePhone = None
			self.invoiceProvice = None
			self.invoiceCity = None
			self.invoiceCounty = None
			self.invoiceAddress = None
			self.doOrderPriceMode = None
			self.orderPriceSnap = None
			self.extContent = None

		def getapiname(self):
			return 'biz.order.unite.submit'

		def get_version(self):
			return '1.0'
			
	

class Sku(object):
		def __init__(self):
			"""
			"""
			self.skuId = None
			self.num = None
			self.bNeedAnnex = None
			self.bNeedGift = None








'''
Created by auto_sdk on 2019.10.21
'''
from third_sdk.top.api.base import RestApi
class OpenuidGetBymixnickRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.mix_nick = None

	def getapiname(self):
		return 'taobao.openuid.get.bymixnick'



'''
Created by auto_sdk on 2019.10.18
'''
from third_sdk.top.api.base import RestApi
class TbkDgOptimusMaterialRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.adzone_id = None
		self.content_id = None
		self.content_source = None
		self.device_encrypt = None
		self.device_type = None
		self.device_value = None
		self.item_id = None
		self.material_id = None
		self.page_no = None
		self.page_size = None

	def getapiname(self):
		return 'taobao.tbk.dg.optimus.material'



'''
Created by auto_sdk on 2019.09.27
'''
from third_sdk.top.api.base import RestApi
class TbkTpwdCreateRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.ext = None
		self.logo = None
		self.text = None
		self.url = None
		self.user_id = None

	def getapiname(self):
		return 'taobao.tbk.tpwd.create'



'''
Created by auto_sdk on 2019.10.18
'''
from third_sdk.top.api.base import RestApi
class TbkDgMaterialOptionalRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.adzone_id = None
		self.cat = None
		self.device_encrypt = None
		self.device_type = None
		self.device_value = None
		self.end_ka_tk_rate = None
		self.end_price = None
		self.end_tk_rate = None
		self.has_coupon = None
		self.include_good_rate = None
		self.include_pay_rate_30 = None
		self.include_rfd_rate = None
		self.ip = None
		self.is_overseas = None
		self.is_tmall = None
		self.itemloc = None
		self.lock_rate_end_time = None
		self.lock_rate_start_time = None
		self.material_id = None
		self.need_free_shipment = None
		self.need_prepay = None
		self.npx_level = None
		self.page_no = None
		self.page_size = None
		self.platform = None
		self.q = None
		self.sort = None
		self.start_dsr = None
		self.start_ka_tk_rate = None
		self.start_price = None
		self.start_tk_rate = None

	def getapiname(self):
		return 'taobao.tbk.dg.material.optional'



from third_sdk.jd.api.base import RestApi

class ServiceActivityInfoReportRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.timeStamp = None
			self.wxAppId = None
			self.pluginAppId = None
			self.activityIdentification = None
			self.activityDescription = None
			self.serviceIdentification = None
			self.wxNickname = None
			self.token = None
			self.wxOpenId = None
			self.pluginOpenId = None
			self.type = None
			self.prizeType = None
			self.rewardDescription = None
			self.typeDescription = None
			self.count = None
			self.resultStatus = None
			self.testData = None

		def getapiname(self):
			return 'jingdong.service.activity.info.report'

			








from third_sdk.jd.api.base import RestApi

class OpenOrderSplitDeliverNewRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.orderExtInfo = None
			self.deliverInfo = None
			self.json = None

		def getapiname(self):
			return 'jingdong.open.order.splitDeliverNew'

			
	

class Attribute2(object):
		def __init__(self):
			"""
			"""
			self.manufactureTime = None
			self.validTime = None
			self.batchNum = None
			self.batchCount = None
			self.skuPrice = None


class Attribute1(object):
		def __init__(self):
			"""
			"""
			self.batchList = None
			self.commonName = None
			self.packageSpec = None
			self.manufacturer = None
			self.venderSku = None
			self.skuName = None
			self.skuPlace = None
			self.skuCount = None
			self.approvalNumber = None


class OrderExtInfo(object):
		def __init__(self):
			"""
			"""
			self.orderAmount = None
			self.sendTime = None
			self.skuList = None
			self.orderId = None


class DeliverInfo(object):
		def __init__(self):
			"""
			"""
			self.deliveryId = None
			self.shipmentType = None
			self.logiCompany = None
			self.customerCode = None
			self.logiNo = None








from third_sdk.jd.api.base import RestApi

class UnionOpenCouponGiftGetRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.couponReq = None

		def getapiname(self):
			return 'jd.union.open.coupon.gift.get'

		def get_version(self):
			return '1.0'
			
	

class CouponReq(object):
		def __init__(self):
			"""
			"""
			self.skuMaterialId = None
			self.discount = None
			self.amount = None
			self.receiveStartTime = None
			self.receiveEndTime = None
			self.effectiveDays = None
			self.isSpu = None
			self.expireType = None
			self.useStartTime = None
			self.useEndTime = None
			self.share = None
			self.contentMatch = None
			self.couponTitle = None
			self.contentMatchMedias = None








from third_sdk.jd.api.base import RestApi

class KeplerSettledAftermarketQueryservicedetailRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.queryServiceDetailParam = None
			self.client = None

		def getapiname(self):
			return 'jd.kepler.settled.aftermarket.queryservicedetail'

		def get_version(self):
			return '1.0'
			
	

class OperatorInfoParam(object):
		def __init__(self):
			"""
			"""
			self.operatorPin = None
			self.operatorName = None
			self.operatorRemark = None
			self.operatorDate = None


class QueryServiceDetailParam(object):
		def __init__(self):
			"""
			"""
			self.afsServiceId = None
			self.buId = None
			self.operatorInfoParam = None


class Client(object):
		def __init__(self):
			"""
			"""
			self.uid = None
			self.userIp = None








from third_sdk.jd.api.base import RestApi

class AfterSaleAfsApplyCreateRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.param = None

		def getapiname(self):
			return 'biz.afterSale.afsApply.create'

		def get_version(self):
			return '1.0'
			
	

class AsCustomerDto(object):
		def __init__(self):
			"""
			"""
			self.customerContactName = None
			self.customerTel = None
			self.customerMobilePhone = None
			self.customerEmail = None
			self.customerPostcode = None


class AsPickwareDto(object):
		def __init__(self):
			"""
			"""
			self.pickwareType = None
			self.pickwareProvince = None
			self.pickwareCity = None
			self.pickwareCounty = None
			self.pickwareVillage = None
			self.pickwareAddress = None


class AsReturnwareDto(object):
		def __init__(self):
			"""
			"""
			self.returnwareType = None
			self.returnwareProvince = None
			self.returnwareCity = None
			self.returnwareCounty = None
			self.returnwareVillage = None
			self.returnwareAddress = None


class AsDetailDto(object):
		def __init__(self):
			"""
			"""
			self.skuId = None
			self.skuNum = None


class Param(object):
		def __init__(self):
			"""
			"""
			self.jdOrderId = None
			self.customerExpect = None
			self.questionDesc = None
			self.isNeedDetectionReport = None
			self.questionPic = None
			self.asCustomerDto = None
			self.asPickwareDto = None
			self.asReturnwareDto = None
			self.asDetailDto = None
			self.isHasPackage = None
			self.packageDesc = None








from third_sdk.jd.api.base import RestApi

class UnionOpenStatisticsGiftcouponQueryRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.effectDataReq = None

		def getapiname(self):
			return 'jd.union.open.statistics.giftcoupon.query'

		def get_version(self):
			return '1.0'
			
	

class EffectDataReq(object):
		def __init__(self):
			"""
			"""
			self.skuId = None
			self.giftCouponKey = None
			self.createTime = None
			self.startTime = None
			self.key = None








from third_sdk.jd.api.base import RestApi

class PopOrderEncryptMobileNumRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.mobile = None

		def getapiname(self):
			return 'jingdong.pop.order.encryptMobileNum'

			








from third_sdk.jd.api.base import RestApi

class KeplerOrderCancelorderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.cancelOrderReq = None
			self.client = None

		def getapiname(self):
			return 'jd.kepler.order.cancelorder'

		def get_version(self):
			return '1.0'
			
	

class CancelOrderReq(object):
		def __init__(self):
			"""
			"""
			self.orderId = None
			self.applyDate = None
			self.applyPin = None
			self.applyName = None


class Client(object):
		def __init__(self):
			"""
			"""
			self.uid = None
			self.userIp = None








from third_sdk.top.api.rest.WangwangClientidBindRequest import WangwangClientidBindRequest
from third_sdk.top.api.rest.TbkDgNewuserOrderGetRequest import TbkDgNewuserOrderGetRequest
from third_sdk.top.api.rest.TbkTpwdCreateRequest import TbkTpwdCreateRequest
from third_sdk.top.api.rest.TbkDgMaterialOptionalRequest import TbkDgMaterialOptionalRequest
from third_sdk.top.api.rest.TmcQueueGetRequest import TmcQueueGetRequest
from third_sdk.top.api.rest.OpenuidGetRequest import OpenuidGetRequest
from third_sdk.top.api.rest.TbkUatmFavoritesGetRequest import TbkUatmFavoritesGetRequest
from third_sdk.top.api.rest.TbkDgVegasTljInstanceReportRequest import TbkDgVegasTljInstanceReportRequest
from third_sdk.top.api.rest.OpenuidGetBytradeRequest import OpenuidGetBytradeRequest
from third_sdk.top.api.rest.FilesGetRequest import FilesGetRequest
from third_sdk.top.api.rest.TbkDgVegasTljCreateRequest import TbkDgVegasTljCreateRequest
from third_sdk.top.api.rest.TbkContentGetRequest import TbkContentGetRequest
from third_sdk.top.api.rest.TbkDgNewuserOrderSumRequest import TbkDgNewuserOrderSumRequest
from third_sdk.top.api.rest.WangwangClientidUnbindRequest import WangwangClientidUnbindRequest
from third_sdk.top.api.rest.OpenuidChangeRequest import OpenuidChangeRequest
from third_sdk.top.api.rest.TopAuthTokenCreateRequest import TopAuthTokenCreateRequest
from third_sdk.top.api.rest.JuItemsSearchRequest import JuItemsSearchRequest
from third_sdk.top.api.rest.AlipayXiaodaiUserPermitRequest import AlipayXiaodaiUserPermitRequest
from third_sdk.top.api.rest.TopAuthTokenRefreshRequest import TopAuthTokenRefreshRequest
from third_sdk.top.api.rest.TmcMsgSendrecordRequest import TmcMsgSendrecordRequest
from third_sdk.top.api.rest.TbkContentEffectGetRequest import TbkContentEffectGetRequest
from third_sdk.top.api.rest.TopSdkFeedbackUploadRequest import TopSdkFeedbackUploadRequest
from third_sdk.top.api.rest.TopSecretRegisterRequest import TopSecretRegisterRequest
from third_sdk.top.api.rest.TmcUserTopicsGetRequest import TmcUserTopicsGetRequest
from third_sdk.top.api.rest.OpenuidGetBymixnickRequest import OpenuidGetBymixnickRequest
from third_sdk.top.api.rest.TopSecretGetRequest import TopSecretGetRequest
from third_sdk.top.api.rest.TbkShopRecommendGetRequest import TbkShopRecommendGetRequest
from third_sdk.top.api.rest.KfcKeywordSearchRequest import KfcKeywordSearchRequest
from third_sdk.top.api.rest.TbkCouponGetRequest import TbkCouponGetRequest
from third_sdk.top.api.rest.TimeGetRequest import TimeGetRequest
from third_sdk.top.api.rest.TopIpoutGetRequest import TopIpoutGetRequest
from third_sdk.top.api.rest.TbkUatmFavoritesItemGetRequest import TbkUatmFavoritesItemGetRequest
from third_sdk.top.api.rest.HttpdnsGetRequest import HttpdnsGetRequest
from third_sdk.top.api.rest.TbkShopGetRequest import TbkShopGetRequest
from third_sdk.top.api.rest.TbkItemInfoGetRequest import TbkItemInfoGetRequest
from third_sdk.top.api.rest.TbkJuTqgGetRequest import TbkJuTqgGetRequest
from third_sdk.top.api.rest.AppipGetRequest import AppipGetRequest
from third_sdk.top.api.rest.TbkActivitylinkGetRequest import TbkActivitylinkGetRequest
from third_sdk.top.api.rest.TbkItemRecommendGetRequest import TbkItemRecommendGetRequest
from third_sdk.top.api.rest.TbkDgOptimusMaterialRequest import TbkDgOptimusMaterialRequest



import hashlib
import time
from urllib.parse import urlencode
import requests


class PddClient:
    """
    拼多多api sdk
    """

    def __init__(self, host="https://gw-api.pinduoduo.com/api/router",
                 appkey='',
                 secert='',
                 timeout=30):
        self.__host = host
        self.__client_id = appkey
        self.__client_secert = secert
        self.__data_type = "JSON"
        self.__timeout = timeout

    @staticmethod
    def __sign_md5(params):
        """
        对拼接好的字符串进行md5签名
        """
        hl = hashlib.md5()
        hl.update(params.encode(encoding='utf-8'))
        return hl.hexdigest().upper()

    @staticmethod
    def __set_real_params(api_type, params={}):
        params['type'] = api_type
        params['timestamp'] = f"{time.time()}".split(".")[0]

    def __set_sys_params(self, params={}):
        params['client_id'] = self.__client_id
        params['data_type'] = self.__data_type

    def __splice_str(self, params={}):
        """
        升序排序请求参数，连接字符串，并在首尾加上client_secret
        """

        reverse_list = sorted([(k, str(v)) for k, v in params.items()], key=lambda x: x[0])
        reverse_list.insert(0, ("", self.__client_secert))
        reverse_list.append(("", self.__client_secert))
        reverse_list_str = list(map(lambda x: "".join(x), reverse_list))
        result = "".join(reverse_list_str)
        return result, params

    def __urlencode_data(self, params, pdd_dict):
        pdd_dict["sign"] = PddClient.__sign_md5(params)
        result = urlencode(pdd_dict)
        url = f"{self.__host}?{result}"
        return url

    def pdd_ddk_goods_detail(self, **kwargs) -> requests.Response:
        """
        多多客商品详情查询接口
        """
        return self.api_invoke("pdd.ddk.goods.detail", **kwargs)

    def pdd_ddk_goods_search(self, **kwargs) -> requests.Response:
        """
        多多客搜索接口
        """
        return self.api_invoke("pdd.ddk.goods.search", **kwargs)

    def pdd_goods_cats_get(self, **kwargs) -> requests.Response:
        """
        商品类目查询接口
        """
        return self.api_invoke("pdd.goods.cats.get", **kwargs)

    def pdd_goods_opt_get(self, **kwargs) -> requests.Response:
        return self.api_invoke("pdd.goods.opt.get", **kwargs)

    def api_invoke(self, api_type, **kwargs) -> requests.Response:
        """
        Api 调用通用方法
        """
        headers = {
            "accept": "application/json",
            'Connection': 'Close',
        }
        params = {}
        # 实时参数
        PddClient.__set_real_params(api_type, params)
        # 系统参数
        self.__set_sys_params(params)
        # 业务参数
        params.update(kwargs)

        params, pdd_dict = self.__splice_str(params)
        url = self.__urlencode_data(params, pdd_dict)
        return requests.post(url=url, headers=headers, timeout=self.__timeout)



from third_sdk.jd.api.base import RestApi

class KeplerPushmsgCreateSubSendTaskRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.param = None

		def getapiname(self):
			return 'jingdong.kepler.pushmsg.createSubSendTask'

			
	

class Param(object):
		def __init__(self):
			"""
			"""
			self.appId = None
			self.contentData = None
			self.businessCode = None
			self.otherParamsData = None
			self.sendTime = None
			self.sendType = None
			self.jumpPage = None
			self.businessId = None
			self.miniprogramState = None
			self.channel = None
			self.taskName = None








from third_sdk import top
import time
import hashlib
import requests
from typing import Union


SYSTEM_GENERATE_VERSION = "taobao-sdk-python-fengjinqi"

P_APPKEY = "app_key"
P_API = "method"
P_SESSION = "session"
P_ACCESS_TOKEN = "access_token"
P_VERSION = "v"
P_FORMAT = "format"
P_TIMESTAMP = "timestamp"
P_SIGN = "sign"
P_SIGN_METHOD = "sign_method"
P_PARTNER_ID = "partner_id"

P_CODE = 'code'
P_SUB_CODE = 'sub_code'
P_MSG = 'msg'
P_SUB_MSG = 'sub_msg'

N_REST = '/router/rest'


class TbClient:

    def __init__(self, host='http://gw.api.taobao.com/router/rest', port=80, appkey='', secret='', timeout=30):
        self.__host = host
        self.__port = port
        self.__appkey = appkey
        self.__secret = secret
        self.__timeout = timeout

    def taobao_tbk_dg_material_optional(self, api: Union[top.api.TbkDgMaterialOptionalRequest, str] = None, access_token=None,
                                        **kwargs) -> requests.Response:
        """
        物料搜索
        """
        if api is None:
            api = top.api.TbkDgMaterialOptionalRequest(self.__host, self.__port)
        return self.api_invoke(api, access_token, **kwargs)

    def taobao_tbk_dg_item_info_get(self, api: Union[top.api.TbkItemInfoGetRequest, str] = None, access_token=None, **kwargs) -> requests.Response:
        """
        商品详情查询(简版)
        """
        if api is None:
            api = top.api.TbkItemInfoGetRequest(self.__host, self.__port)
        return self.api_invoke(api, access_token, **kwargs)

    def api_invoke(self, api: Union[top.api.base.RestApi, str], access_token=None, method='POST', **kwargs) -> requests.Response:
        """
        api 调用通用方法
        """
        assert api is not None
        if type(api) == str:
            return _api_invoke(self.__host, method, self.__appkey, self.__secret, api, access_token, self.__timeout, **kwargs)
        api.set_app_info(top.appinfo(self.__appkey, self.__secret))
        for k, v in kwargs.items():
            setattr(api, k, v)
        return api.getResponse(authrize=access_token, timeout=self.__timeout)


def _get_request_header():
    return {
             'Content-type': 'application/x-www-form-urlencoded;charset=UTF-8',
             "Cache-Control": "no-cache",
             "Connection": "Close",
    }


def _get_application_parameters(**kwargs):
    p = {}
    for key, value in kwargs.items():
        if key and value:
            if key.startswith("_"):
                p[key[1:]] = value
            else:
                p[key] = value
    return p


def _sign(sec, parameters):
    # ===========================================================================
    # '''签名方法
    # @param sec: 签名需要的密钥
    # @param parameters: 支持字典和string两种
    # '''
    # ===========================================================================
    # 如果parameters 是字典类的话
    if hasattr(parameters, "items"):
        keys = list(parameters.keys())
        keys.sort()

        parameters = "%s%s%s" % (sec,
                                 str().join('%s%s' % (key, parameters[key]) for key in keys),
                                 sec)
    return hashlib.md5(parameters.encode('utf8')).hexdigest().upper()


def _api_invoke(domain, http_method, appkey, secret, apiname, access_token, timeout, **kwargs):
    sys_parameters = {
        P_FORMAT: 'json',
        P_APPKEY: appkey,
        P_SIGN_METHOD: "md5",
        P_VERSION: '2.0',
        P_TIMESTAMP: str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(time.time()))),
        P_PARTNER_ID: SYSTEM_GENERATE_VERSION,
        P_API: apiname,
    }
    if access_token is not None:
        sys_parameters[P_SESSION] = access_token
    application_parameter = _get_application_parameters(**kwargs)
    sign_parameter = sys_parameters.copy()
    sign_parameter.update(application_parameter)
    sys_parameters[P_SIGN] = _sign(secret, sign_parameter)
    sys_parameters.update(sign_parameter)

    header = _get_request_header()
    return requests.request(http_method, domain, data=sys_parameters, headers=header, timeout=timeout)



from third_sdk.jd.api.base import RestApi

class KplOpenPromotionPidurlconvertRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.webId = None
			self.positionId = None
			self.materalId = None
			self.pid = None
			self.subUnionId = None
			self.shortUrl = None
			self.kplClick = None

		def getapiname(self):
			return 'jd.kpl.open.promotion.pidurlconvert'

		def get_version(self):
			return '1.0'
			
	







from third_sdk.jd.api.base import RestApi

class KplOpenYaoOrdersyncUpdatestateRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.venderId = None
			self.orderId = None
			self.deliverInfo = None

		def getapiname(self):
			return 'jd.kpl.open.yao.ordersync.updatestate'

		def get_version(self):
			return '1.0'
			
	

class DeliverInfo(object):
		def __init__(self):
			"""
			"""
			self.shipmentType = None
			self.customerCode = None
			self.deliveryId = None
			self.logiNo = None
			self.logiCompany = None








import hashlib
import json
import time
import hmac
from hashlib import sha256
import requests
from urllib.parse import urlencode


def md5(s):
    m = hashlib.md5()
    m.update(s.encode('utf-8'))
    return m.hexdigest()


def hmac_sha256(k, s):
    m = hmac.new(k, s, digestmod=sha256)
    return m.hexdigest()


def _get_sort_dict(dict_val):
    new_val = {}
    keys = sorted(list(dict_val.keys()))
    for k in keys:
        new_val[k] = dict_val[k]
    return new_val


class DouDianClient:
    """
    抖店客户端
    使用方式:
        def get_access_token():
            return 'xxxxx'
        client = DouDianClient(appkey='xxx', secret='xxx', get_access_token_func=get_access_token)

        resp = client.api_invoke('xxx', version='1', **{
            'xxx': 'xxxxx'
        })
    """

    __default_headers = {
        'Connection': 'Close',
    }

    def __init__(self, host='openapi-fxg.jinritemai.com', appkey='', secret='', get_access_token_func=None):
        self.__host = host if host.startswith("http") else 'https://' + host
        self.__appkey = appkey
        self.__secret = secret
        self.__get_access_token_func = get_access_token_func

    def buyin_kolMaterialsProductsSearch(self, **kwargs) -> requests.Response:
        """
        抖店达人商品搜索
        """
        return self.api_invoke('buyin.kolMaterialsProductsSearch', version='2', **kwargs)

    def api_invoke(self, api_name: str, version="1", **kwargs) -> requests.Response:
        """
        API 调用接口
        :param api_name: api名称
        :param version:  api版本
        :param kwargs: api应用参数
        :return: requests.Response
        """
        now = int(time.time())
        api_path = "/" + api_name.replace('.', "/")
        params = _get_sort_dict(kwargs)
        sign = self._get_sign(api_name, version, now, params)
        query = {
            'method': api_name,
            'app_key': self.__appkey,
            'access_token': self.__get_access_token_func(),
            'timestamp': now,
            'v': version,
            'sign_method': 'hmac-sha256',
            'sign': sign
        }
        query = _get_sort_dict(query)
        url = self.__host + api_path + '?' + urlencode(query)
        return requests.post(url, json=params, headers=self.__default_headers)

    def _get_sign(self, api_name, version, timestamp, params):
        s = f'{self.__secret}app_key{self.__appkey}method{api_name}param_json{json.dumps(params, ensure_ascii=False).replace(" ", "")}timestamp{timestamp}v{version}{self.__secret}'
        return hmac_sha256(self.__secret.encode('utf-8'), s.encode('utf-8'))
